@@ -351,9 +351,9 @@ class LPMain:
                     df[var.name]=var.result
                 if df.shape[1]>1:
                     df.to_excel(writer,sheet_name=f'{name} - Results',index=False)
-        self.optimize_excel_col_width(path)
+        self.__optimize_excel_col_width(path)
         
-    def optimize_excel_col_width(self,path):
+    def __optimize_excel_col_width(self,path):
         '''
         optimizes the width of the excel columns so the full title of each column can be read
         '''
@@ -447,10 +447,10 @@ class LPMain:
                         if first_timeindex is None:
                             first_timeindex = t_step
                     timesteps_lst.append(first_timeindex)
-                timesteps_str = f'für t = [{self.summarize_intervals(timesteps_lst)}]'
+                timesteps_str = f'für t = [{self.__summarize_intervals(timesteps_lst)}]'
                 label = ttk.Label(frame, text=timesteps_str, anchor="center")
                 label.pack(pady=10, fill=tk.BOTH)
-                fig = self.create_figure_for_display(eq)
+                fig = self.__create_figure_for_display(eq)
                 canvas = FigureCanvasTkAgg(fig, master=frame)
                 canvas.draw()
                 canvas.get_tk_widget().pack(side=tk.TOP, fill=tk.BOTH, expand=True) 
@@ -462,7 +462,7 @@ class LPMain:
         root.attributes('-topmost', 0)  # Reset the topmost attribute
         root.mainloop()
         
-    def summarize_intervals(self,lst):
+    def __summarize_intervals(self,lst):
         output = []
         i = 0
         while i < len(lst):
@@ -477,16 +477,16 @@ class LPMain:
             i += 1
         return ', '.join(output)
     
-    def create_figure_for_display(self,eq):
+    def __create_figure_for_display(self,eq):
         fig, ax = plt.subplots(figsize=(1.5,  0.5))  # Anpassen der Höhe an die Anzahl der Gleichungen #!anpassen
         ax.axis('off')
 
         y_position = 0.4
-        fig.text(0.5, y_position, f"${sp.latex(self.convert_to_sympy_equation(eq))}$", fontsize=12, ha='center', va='center')    
+        fig.text(0.5, y_position, f"${sp.latex(self.__convert_to_sympy_equation(eq))}$", fontsize=12, ha='center', va='center')    
 
         return fig
 
-    def convert_to_sympy_equation(self,equation):
+    def __convert_to_sympy_equation(self,equation):
         # Initialize the left-hand side as 0
         lhs = 0
         first_timeindex=None
